Welcome to PrettyQt's documentation!
======================================

PrettyQt is a thin wrapper for PyQt5 / PySide2 APIs.

Source code
   https://github.com/phil65/prettyqt


.. toctree::
   :maxdepth: 4
   :caption: PrettyQt

   readme
   installation
   usage

.. toctree::
   :maxdepth: 4
   :caption: API

   modules
   api

.. toctree::
   :maxdepth: 4
   :caption: Other stuff

   contributing
   authors
   history


main
===================
.. automodule:: prettyqt.core
   :members:
   :show-inheritance:

.. automodule:: prettyqt.widgets
   :members:
   :show-inheritance:
